==> react-atom-video-player-1.10.0.tgz: package/lib/components/VimeoPlayer.js <==
import { useRef } from 'react';
import PropTypes from 'prop-types';
import { toQueryString } from '@s-ui/js/lib/string';
import useTimeLimitCheck from '../hooks/vimeo/useTimeLimitCheck.js';
import useVimeoProperties from '../hooks/vimeo/useVimeoProperties.js';
import { BASE_CLASS, VIMEO_DEFAULT_TITLE } from '../settings/index.js';
import { jsx as _jsx } from "react/jsx-runtime";
var VimeoPlayer = function VimeoPlayer(_ref) {
  var autoPlay = _ref.autoPlay,
    controls = _ref.controls,
    timeLimit = _ref.timeLimit,
    timeOffset = _ref.timeOffset,
    src = _ref.src,
    _ref$title = _ref.title,
    title = _ref$title === void 0 ? VIMEO_DEFAULT_TITLE : _ref$title;
  var _useVimeoProperties = useVimeoProperties(),
    getEmbeddableUrl = _useVimeoProperties.getEmbeddableUrl;
  var params = toQueryString({
    controls: controls ? '1' : '0',
    autoplay: autoPlay ? '1' : '0'
  });
  var time = "#t=" + timeOffset;
  var videoSrc = getEmbeddableUrl(src) + "?" + params + time;
  var playerRef = useRef(null);
  useTimeLimitCheck({
    playerRef: playerRef,
    timeLimit: timeLimit,
    timeOffset: timeOffset
  });
  return /*#__PURE__*/_jsx("div", {
    className: BASE_CLASS + "-vimeoPlayer",
    children: /*#__PURE__*/_jsx("iframe", {
      className: BASE_CLASS + "-vimeoPlayerFrame",
      title: title,
      src: videoSrc,
      frameBorder: "0",
      allow: "autoplay; fullscreen; picture-in-picture",
      allowFullScreen: true,
      ref: playerRef
    })
  });
};
export default VimeoPlayer;

==> react-atom-video-player-1.13.0.tgz: package/lib/components/VimeoPlayer.js <==
import { useRef } from 'react';
import PropTypes from 'prop-types';
import { toQueryString } from '@s-ui/js/lib/string';
import useTimeLimitCheck from '../hooks/vimeo/useTimeLimitCheck.js';
import useVimeoProperties from '../hooks/vimeo/useVimeoProperties.js';
import { BASE_CLASS, VIMEO_DEFAULT_TITLE } from '../settings/index.js';
import { jsx as _jsx } from "react/jsx-runtime";
var VimeoPlayer = function VimeoPlayer(_ref) {
  var autoPlay = _ref.autoPlay,
    controls = _ref.controls,
    muted = _ref.muted,
    timeLimit = _ref.timeLimit,
    timeOffset = _ref.timeOffset,
    src = _ref.src,
    _ref$title = _ref.title,
    title = _ref$title === void 0 ? VIMEO_DEFAULT_TITLE : _ref$title;
  var _useVimeoProperties = useVimeoProperties(),
    getEmbeddableUrl = _useVimeoProperties.getEmbeddableUrl;
  var params = toQueryString({
    autoplay: autoPlay ? '1' : '0',
    controls: controls ? '1' : '0',
    muted: muted ? '1' : '0'
  });
  var time = "#t=" + timeOffset;
  var videoSrc = getEmbeddableUrl(src) + "?" + params + time;
  var playerRef = useRef(null);
  useTimeLimitCheck({
    playerRef: playerRef,
    timeLimit: timeLimit,
    timeOffset: timeOffset
  });
  return /*#__PURE__*/_jsx("div", {
    className: BASE_CLASS + "-vimeoPlayer",
    children: /*#__PURE__*/_jsx("iframe", {
      className: BASE_CLASS + "-vimeoPlayerFrame",
      title: title,
      src: videoSrc,
      frameBorder: "0",
      allow: "autoplay; fullscreen; picture-in-picture",
      allowFullScreen: true,
      ref: playerRef
    })
  });
};
export default VimeoPlayer;
